@@ -1,18 +1,14 @@
 
-from sklearn import metrics  # 0.0.0
-from sklearn.ensemble import RandomForestClassifier
-from sklearn.model_selection import train_test_split
-from sklearn import datasets
 import pandas as pd  # 1.0.1
-import pymongo  # 3.10.1
 import json
 import joblib  # 0.14.1
 from sklearn.feature_extraction import DictVectorizer
-from gcloud import storage
+import time
 
 loaded_model = joblib.load('finalized_model.sav')
 
 def spectator_classifier(game_list):
+    t1 = time.time()
     vecArr = []
     v = DictVectorizer(sparse=False)
 
@@ -29,5 +25,8 @@ def spectator_classifier(game_list):
     data = pd.DataFrame(vecArr)
     data.head()
     z_pred = loaded_model.predict(list(data['participants']))
-    return {'pred': z_pred}
+    t2 = time.time()
+    print(t2-t1)
+    
+    return z_pred
 
